==> teamapps-client-0.9.89.zip: tsd/modules/workspace-layout/UiWorkSpaceLayoutChildWindowTeamAppsUiContext.d.ts <==
import { UiComponentConfig } from "../../generated/UiComponentConfig";
import { TeamAppsUiContext, TeamAppsUiContextInternalApi } from "../TeamAppsUiContext";
import { UiConfigurationConfig } from "../../generated/UiConfigurationConfig";
import { UiEvent } from "../../generated/UiEvent";
import { TemplateRegistry } from "../TemplateRegistry";
import { TeamAppsEvent } from "../util/TeamAppsEvent";
import { UiCommand } from "../../generated/UiCommand";
import { UiComponent } from "../UiComponent";
export declare class UiWorkSpaceLayoutChildWindowTeamAppsUiContext implements TeamAppsUiContext, TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    private _sessionId;
    readonly isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private workSpaceLayout;
    private parentWindowMessagePort;
    private _executingCommand;
    private components;
    constructor();
    private static isINIT_OK;
    get sessionId(): string;
    get executingCommand(): boolean;
    fireEvent(eventObject: UiEvent): void;
    registerClientObject(component: UiComponent<UiComponentConfig>, id: string, teamappsType: string): void;
    destroyClientObject(id: string): void;
    createClientObject(config: UiComponentConfig): UiComponent<UiComponentConfig>;
    getClientObjectById(id: string): UiComponent<UiComponentConfig>;
    refreshComponent(config: UiComponentConfig): void;
}

==> teamapps-client-0.9.103.zip: tsd/modules/workspace-layout/UiWorkSpaceLayoutChildWindowTeamAppsUiContext.d.ts <==
import { UiComponentConfig } from "../../generated/UiComponentConfig";
import { TeamAppsUiContext, TeamAppsUiContextInternalApi } from "../TeamAppsUiContext";
import { UiConfigurationConfig } from "../../generated/UiConfigurationConfig";
import { UiEvent } from "../../generated/UiEvent";
import { TemplateRegistry } from "../TemplateRegistry";
import { TeamAppsEvent } from "../util/TeamAppsEvent";
import { UiCommand } from "../../generated/UiCommand";
import { UiComponent } from "../UiComponent";
export declare class UiWorkSpaceLayoutChildWindowTeamAppsUiContext implements TeamAppsUiContext, TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    private _sessionId;
    readonly isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private workSpaceLayout;
    private parentWindowMessagePort;
    private _executingCommand;
    private components;
    constructor();
    private static isINIT_OK;
    get sessionId(): string;
    get executingCommand(): boolean;
    sendEvent(eventObject: UiEvent): void;
    registerClientObject(component: UiComponent<UiComponentConfig>, id: string, teamappsType: string): void;
    destroyClientObject(id: string): void;
    createClientObject(config: UiComponentConfig): UiComponent<UiComponentConfig>;
    getClientObjectById(id: string): UiComponent<UiComponentConfig>;
    refreshComponent(config: UiComponentConfig): void;
}
